pub struct Point {
pub index: usize,
pub line: usize,
pub col: usize,
}Expand description
represents a position in a file, both in terms of (line, col) and
in terms of seek index from the file
Fields
index: usizeRaw seek index. This point is the index element of the file as a stream. 0 indexed
line: usizethe line number of the point. 0 indexed
col: usizethe column number of the point. 0 indexed
Implementations